@@ -1,5 +1,5 @@
 var searchData=
 [
   ['passing_20a_20remote_20command_0',['Chapter 4: Passing a remote command',['../libssh_tutor_command.html',1,'libssh_tutorial']]],
-  ['pkcs_2011_20uris_1',['Chapter 9: Authentication using PKCS #11 URIs',['../libssh_tutor_pkcs11.html',1,'']]]
+  ['pkcs_2011_20uris_1',['Chapter 9: Authentication using PKCS #11 URIs',['../libssh_tutor_pkcs11.html',1,'libssh_tutorial']]]
 ];
